==> hs-comonad-transformers-2.0.0.tbz: lib/ghc-7.0.3/cabal/comonad-transformers-2.0.0/register.sh <==
#!/bin/sh
echo 'name: comonad-transformers
version: 2.0.0
id: comonad-transformers-2.0.0-c3e59a7d91b79aad007eec8e072a3e33

license: BSD3
copyright: Copyright (C) 2008-2011 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/comonad-transformers/
package-url:
description: Comonad transformers
category: Control, Comonads
author: Edward A. Kmett
exposed: True
exposed-modules: Control.Comonad.Hoist.Class
                 Control.Comonad.Trans.Class Control.Comonad.Trans.Discont
                 Control.Comonad.Trans.Discont.Lazy
                 Control.Comonad.Trans.Discont.Strict
                 Control.Comonad.Trans.Discont.Memo Control.Comonad.Trans.Env
                 Control.Comonad.Trans.Env.Lazy Control.Comonad.Trans.Env.Strict
                 Control.Comonad.Trans.Identity Control.Comonad.Trans.Store
                 Control.Comonad.Trans.Store.Lazy Control.Comonad.Trans.Store.Strict
                 Control.Comonad.Trans.Store.Memo Control.Comonad.Trans.Traced
                 Control.Comonad.Trans.Traced.Memo Data.Functor.Coproduct
                 Data.Functor.Composition
hidden-modules:
import-dirs: /usr/local/lib/ghc-7.0.3/cabal/comonad-transformers-2.0.0
library-dirs: /usr/local/lib/ghc-7.0.3/cabal/comonad-transformers-2.0.0
              /usr/local/lib
hs-libraries: HScomonad-transformers-2.0.0
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.3.1.0-93a63ba911a7eac625848432374f7fee
         comonad-1.1.1-b79e4cf1aaa56be9ca2e35691b2f9a4a
         containers-0.4.0.0-18deac99a132f04751d862b77aab136e
         contravariant-0.1.2.1-682eef3d08797e87f964cdf4c634b07f
         distributive-0.2.0.1-58711149ed16d05254a1bb9aad5b8405
         semigroupoids-1.2.5-f6e3de8c26bde4f43361f228f3b50c54
         semigroups-0.7.1-deb342a601060f02978392f99248f4b1
         transformers-0.2.2.0-a8a2dbba7d96131db605cf631ea0c8c4
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.3/cabal/comonad-transformers-2.0.0/html/comonad-transformers.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.3/cabal/comonad-transformers-2.0.0/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-comonad-transformers-2.0.2.tbz: lib/ghc-7.0.4/cabal/comonad-transformers-2.0.2/register.sh <==
#!/bin/sh
echo 'name: comonad-transformers
version: 2.0.2
id: comonad-transformers-2.0.2-0adbadbb3d754e35d916c7c3fbf0e54f

license: BSD3
copyright: Copyright (C) 2008-2011 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/comonad-transformers/
package-url:
description: Comonad transformers
category: Control, Comonads
author: Edward A. Kmett
exposed: True
exposed-modules: Control.Comonad.Hoist.Class
                 Control.Comonad.Trans.Class Control.Comonad.Trans.Discont
                 Control.Comonad.Trans.Discont.Lazy
                 Control.Comonad.Trans.Discont.Strict
                 Control.Comonad.Trans.Discont.Memo Control.Comonad.Trans.Env
                 Control.Comonad.Trans.Env.Lazy Control.Comonad.Trans.Env.Strict
                 Control.Comonad.Trans.Identity Control.Comonad.Trans.Store
                 Control.Comonad.Trans.Store.Lazy Control.Comonad.Trans.Store.Strict
                 Control.Comonad.Trans.Store.Memo Control.Comonad.Trans.Traced
                 Control.Comonad.Trans.Traced.Memo Data.Functor.Coproduct
                 Data.Functor.Composition
hidden-modules:
import-dirs: /usr/local/lib/ghc-7.0.4/cabal/comonad-transformers-2.0.2
library-dirs: /usr/local/lib/ghc-7.0.4/cabal/comonad-transformers-2.0.2
              /usr/local/lib
hs-libraries: HScomonad-transformers-2.0.2
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.3.1.0-93a63ba911a7eac625848432374f7fee
         comonad-1.1.1.1-11948d68e66bfe41c66ae1dd32767483
         containers-0.4.0.0-18deac99a132f04751d862b77aab136e
         contravariant-0.1.3-2cb3acc40ed611171f3c57c159066205
         distributive-0.2.0.1-58711149ed16d05254a1bb9aad5b8405
         semigroupoids-1.2.6.1-b190e01014ed9477d0d4bcb981fa39d8
         semigroups-0.8-6e8534570e05e3bb18ad64bd377c39d2
         transformers-0.2.2.0-a8a2dbba7d96131db605cf631ea0c8c4
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.4/cabal/comonad-transformers-2.0.2/html/comonad-transformers.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.4/cabal/comonad-transformers-2.0.2/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
